@@ -179,6 +179,7 @@ class CvsWrapperBase(object):
         if self._wrkPath is not None and len(self._wrkPath) > 0:
             try:
                 shutil.rmtree(self._wrkPath)
+                self._wrkPath = None
                 return True
             except Exception as e:
                 self.__lfh.write("cleanup - unable to remove self._wrkpath")
@@ -203,7 +204,7 @@ class CvsAdmin(CvsWrapperBase):
         """
         text = ""
         ok = False
-        cmd = self.__getHistoryCmd(cvsPath)
+        cmd = self.__getHistoryCmd(cvsPath, True)
         if cmd is not None:
             ok = self._runCvsCommand(myCommand=cmd)
             text = self._getOutputText()
@@ -254,13 +255,19 @@ class CvsAdmin(CvsWrapperBase):
 
         return (ok, text)
 
-    def __getHistoryCmd(self, cvsPath):
+    def __getHistoryCmd(self, cvsPath, incldel=False):
+        """Generate command to retrieve history.  If incldel is set, include removed revisions"""
         if self._wrkPath is None:
             self._makeTempWorkingDir()
         outPath = self._getOutputFilePath()
         errPath = self._getErrorFilePath()
+
+        if incldel:
+            opts = "AMR "
+        else:
+            opts = "AM "
         if self._setCvsRoot():
-            cmd = "cvs -d " + self._cvsRoot + " history -a -x AM " + cvsPath + self._getRedirect(fileNameOut=outPath, fileNameErr=errPath)
+            cmd = "cvs -d " + self._cvsRoot + " history -a -x " + opts + cvsPath + self._getRedirect(fileNameOut=outPath, fileNameErr=errPath)
         else:
             cmd = None
         return cmd
@@ -534,7 +541,10 @@ class CvsSandBoxAdmin(CvsWrapperBase):
             #
             if saveCopy:
                 (_pth, fn) = os.path.split(relProjectPath)
-                savePath = os.path.join(self.__sandBoxTopPath, projectDir, "REMOVED", fn)
+                folder_removed = os.path.join(self.__sandBoxTopPath, projectDir, "REMOVED")
+                if not os.path.isdir(folder_removed):
+                    os.mkdir(folder_removed)
+                savePath = os.path.join(folder_removed, fn)
 
                 # relSavePath = os.path.join("REMOVED", fn)
                 shutil.copyfile(targetPath, savePath)
